SystemOrganization addCategory: #'Seaside-Tests-Security'!

!GRPackage class methodsFor: '*seaside-tests-security' stamp: 'pmm 2/8/2014 16:20'!
seasideTestsSecurity
	^ self new
		name: 'Seaside-Tests-Security';
		addDependency: 'Seaside-Security';
		addDependency: 'Seaside-Tests-Core';
		url: #seasideUrl;
		yourself! !

WARequestHandler subclass: #WAEmptyHandler
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Security'!

!WAEmptyHandler methodsFor: 'processing' stamp: 'pmm 2/9/2014 12:34'!
handleFiltered: aRequestContext
	! !

!WAResponseTest methodsFor: '*seaside-tests-security' stamp: 'pmm 2/6/2014 16:09'!
testNoSniff
	self response noSniff.
	self assert: (self response headerAt: 'X-Content-Type-Options') = 'nosniff'.
	self assert: (self response headers size) = 1! !

TestCase subclass: #WAFrameOptionsAllowFromFilterTest
	instanceVariableNames: 'filter'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Security'!

!WAFrameOptionsAllowFromFilterTest methodsFor: 'private' stamp: 'pmm 8/1/2014 09:00'!
newFilter
	^ WAFrameOptionsAllowFromFilter new! !

!WAFrameOptionsAllowFromFilterTest methodsFor: 'running' stamp: 'pmm 8/1/2014 09:00'!
setUp
	super setUp.
	filter := self newFilter! !

!WAFrameOptionsAllowFromFilterTest methodsFor: 'testing' stamp: 'pmm 8/1/2014 09:04'!
testAddHeader
	| context request response |
	request := WARequest method: 'GET' uri: '/login.do?username=admin'.
	response := WABufferedResponse new.
	
	context := WARequestContext request: request response: response.
	filter setNext: WAEmptyHandler new.
	filter configuration at: #origin put: 'http://www.seaside.st'.
	[  filter handleFiltered: context ]
		on: WAResponseNotification
		do: [ :notification | ].
		
	self assert: response status = WAResponse statusOk.
	self assert: (response headerAt: 'X-Frame-Options') = 'ALLOW FROM http://www.seaside.st'! !

TestCase subclass: #WAFrameOptionsFilterTest
	instanceVariableNames: 'filter'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Security'!

!WAFrameOptionsFilterTest methodsFor: 'private' stamp: 'pmm 8/1/2014 08:48'!
newFilter
	^ WAFrameOptionsFilter new! !

!WAFrameOptionsFilterTest methodsFor: 'running' stamp: 'pmm 8/1/2014 08:48'!
setUp
	super setUp.
	filter := self newFilter! !

!WAFrameOptionsFilterTest methodsFor: 'testing' stamp: 'pmm 8/1/2014 09:03'!
testAddHeader
	| context request response |
	request := WARequest method: 'GET' uri: '/login.do?username=admin'.
	response := WABufferedResponse new.
	
	context := WARequestContext request: request response: response.
	filter setNext: WAEmptyHandler new.
	[  filter handleFiltered: context ]
		on: WAResponseNotification
		do: [ :notification | ].
		
	self assert: response status = WAResponse statusOk.
	self assert: (response headerAt: 'X-Frame-Options') = 'DENY'! !

TestCase subclass: #WANoSniffFilterTest
	instanceVariableNames: 'filter'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Security'!

!WANoSniffFilterTest methodsFor: 'private' stamp: 'pmm 2/9/2014 12:40'!
newFilter
	^ WANoSniffFilter new! !

!WANoSniffFilterTest methodsFor: 'running' stamp: 'pmm 2/9/2014 12:40'!
setUp
	super setUp.
	filter := self newFilter! !

!WANoSniffFilterTest methodsFor: 'testing' stamp: 'pmm 2/9/2014 12:41'!
testAddHeader
	| context request response |
	request := WARequest method: 'GET' uri: '/login.do?username=admin'.
	response := WABufferedResponse new.
	
	context := WARequestContext request: request response: response.
	filter setNext: WAEmptyHandler new.
	[  filter handleFiltered: context ]
		on: WAResponseNotification
		do: [ :notification | ].
		
	self assert: response status = WAResponse statusOk.
	self assert: (response headerAt: 'X-Content-Type-Options') = 'nosniff'! !

TestCase subclass: #WAStrictTransportSecurityFilterTest
	instanceVariableNames: 'filter'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Security'!

!WAStrictTransportSecurityFilterTest methodsFor: 'private' stamp: 'pmm 2/9/2014 12:13'!
newFilter
	^ WAStrictTransportSecurityFilter new! !

!WAStrictTransportSecurityFilterTest methodsFor: 'running' stamp: 'pmm 2/9/2014 12:12'!
setUp
	super setUp.
	filter := self newFilter! !

!WAStrictTransportSecurityFilterTest methodsFor: 'testing' stamp: 'pmm 2/9/2014 12:35'!
testAddHeaderWithSsl
	| context request response |
	request := WARequest method: 'GET' uri: '/login.do?username=admin'.
	request url scheme: 'https'.
	request headers at: 'host' put: 'bank.com'.
	response := WABufferedResponse new.
	self assert: request isSsl.
	
	context := WARequestContext request: request response: response.
	filter setNext: WAEmptyHandler new.
	[  filter handleFiltered: context ]
		on: WAResponseNotification
		do: [ :notification | ].
		
	self assert: response status = WAResponse statusOk.
	self assert: (response headerAt: 'Strict-Transport-Security') = 'max-age=1209600'! !

!WAStrictTransportSecurityFilterTest methodsFor: 'testing' stamp: 'pmm 2/9/2014 12:25'!
testRedirectNoSsl
	| context request response |
	request := WARequest method: 'GET' uri: '/login.do?username=admin'.
	request headers at: 'host' put: 'bank.com'.
	response := WABufferedResponse new.
	self deny: request isSsl.
	
	context := WARequestContext request: request response: response.
	[  filter handleFiltered: context ]
		on: WAResponseNotification
		do: [ :notification | ].
		
	self assert: response status = WAResponse statusFound.
	self assert: ((response headerAt: 'Location') beginsWith: 'https://')! !
